import base64


def get_data_uri_image(file, filetype='png'):
    with open(file, 'rb') as image:
        return transform_image_to_data_uri(image.read(), filetype)


def transform_image_to_data_uri(image, filetype='png', gift_escape=True):
    data_uri = 'data:image/' + filetype + ';base64,' + base64.b64encode(image).decode("utf-8")

    # : and = must be escaped inside the question content for gift and moodle import
    if gift_escape:
        data_uri = data_uri.replace(":", "\\:")
        data_uri = data_uri.replace("=", "\\=")

    return data_uri



import setuptools


def readme():
    with open('README.md') as f:
        return f.read()


setuptools.setup(name='giftsnippet',
      version='0.2.0',
      description='Integrate highlighted source code images with data uris into your gift questions',
      long_description=readme(),
      long_description_content_type='text/markdown',
      keywords='gift moodle code-formatting',
      url='http://github.com/stefanhuber/giftsnippet',
      author='Stefan Huber',
      author_email='mail@stefanhuber.at',
      license='BSD',
      packages=['giftsnippet'],
      install_requires=["Pygments", "Pillow"],
      test_suite="giftsnippet.tests",
      include_package_data=True,
      zip_safe=False,
     entry_points={
         'console_scripts': ['giftsnippet=giftsnippet.console:main'],
     })



import os
from pygments import highlight
from pygments.lexers import get_lexer_by_name
from pygments.formatters import get_formatter_by_name
from .image import transform_image_to_data_uri


def get_lexer_from_filetype(filetype='py'):
    mapping = {
        'py': 'python'
    }

    if filetype in mapping:
        return mapping[filetype]
    else:
        raise ValueError('Filetype ' + filetype + ' not supported')


def get_data_uri_snippet(file, filetype='py', gift_escape=True):
    lexer = get_lexer_from_filetype(filetype)
    snippet = load_snippet(file)
    image = highlight(snippet, get_lexer_by_name(lexer), get_formatter_by_name('png'))
    return transform_image_to_data_uri(image)


def load_snippet(file):
    assert os.path.exists(file)
    with open(file) as file_object:
        return file_object.read()
